@@ -1,10 +1,11 @@
 package CPANPLUS::Config::YACSmoke;
+$CPANPLUS::Config::YACSmoke::VERSION = '1.03_01'; # TRIAL
+
+$CPANPLUS::Config::YACSmoke::VERSION = '1.0301';# Dist::Zilla: +PodWeaver
+#ABSTRACT: Set the environment for YACSmoking
 
 use strict;
 use File::Spec;
-use vars qw($VERSION);
-
-$VERSION = '1.00';
 
 sub setup {
   my $conf = shift;
@@ -17,10 +18,18 @@ sub setup {
 
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 CPANPLUS::Config::YACSmoke - Set the environment for YACSmoking
 
+=head1 VERSION
+
+version 1.03_01
+
 =head1 SYNOPSIS
 
   export PERL5_YACSMOKE_BASE=/home/moo/perls/conf/perl-5.8.9/
@@ -30,7 +39,7 @@ CPANPLUS::Config::YACSmoke - Set the environment for YACSmoking
 CPANPLUS::Config::YACSmoke is a L<CPANPLUS::Config> file that allows the CPAN Tester to
 specify where L<CPANPLUS::YACSmoke> and L<CPANPLUS> get their configuration from.
 
-Setting the environment variable C<PERL5_YACSMOKE_BASE> to a path location, determines 
+Setting the environment variable C<PERL5_YACSMOKE_BASE> to a path location, determines
 where the C<.cpanplus> directory will be located.
 
 =head1 METHODS
@@ -43,20 +52,23 @@ Called by L<CPANPLUS::Configure>.
 
 =back
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
+=head1 KUDOS
 
 Contributions and patience from Jos Boumans the L<CPANPLUS> guy!
 
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams and Jos Boumans.
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<CPANPLUS>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Chris Williams, Jos Boumans, Robert Rothenberg and Barbie.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
