@@ -1,4 +1,8 @@
 package CPANPLUS::Dist::YACSmoke;
+$CPANPLUS::Dist::YACSmoke::VERSION = '1.03_01'; # TRIAL
+
+$CPANPLUS::Dist::YACSmoke::VERSION = '1.0301';# Dist::Zilla: +PodWeaver
+#ABSTRACT: CPANPLUS distribution class that integrates CPAN Testing services into CPANPLUS
 
 use strict;
 use warnings;
@@ -18,10 +22,6 @@ use File::Spec::Functions;
 use CPANPLUS::YACSmoke::ReAssemble;
 use CPANPLUS::YACSmoke::IniFiles;
 
-use vars qw($VERSION);
-
-$VERSION = '1.00';
-
 use constant DATABASE_FILE => 'cpansmoke.dat';
 use constant CONFIG_FILE   => 'cpansmoke.ini';
 
@@ -133,7 +133,7 @@ my %throw_away;
 		  $report =~ s/\[MSG\].*may need to build a \'CPANPLUS::Dist::YACSmoke\' package for it as well.*?\n//sg;
       $report =~ s/\[MSG\] \[[\w: ]+\] Extracted '\S*?'\n//sg;
 		  $report .=
-			"\nThis report was machine-generated by CPANPLUS::Dist::YACSmoke $VERSION.\n";
+			"\nThis report was machine-generated by CPANPLUS::Dist::YACSmoke $CPANPLUS::Dist::YACSmoke::VERSION.\n";
 		  if ( $ENV{PERL5_MINIYACSMOKER} ) {
 			$report .= "Powered by miniyacsmoker version " . $ENV{PERL5_MINIYACSMOKER} . "\n";
 		  }
@@ -362,13 +362,22 @@ ADDREPORT
 
 }
 
-1;
+'Yakkity Yac';
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 CPANPLUS::Dist::YACSmoke - CPANPLUS distribution class that integrates CPAN Testing services into CPANPLUS
 
+=head1 VERSION
+
+version 1.03_01
+
 =head1 SYNOPSIS
 
   # CPANPLUS shell - use CPANPLUS::Dist::YACSmoke services during manual use.
@@ -423,7 +432,7 @@ CPANPLUS::Dist::YACSmoke overrides a number of methods provided by L<CPANPLUS::D
 =item C<init>
 
 This method is called just after the new dist object is set up. It initialises the database file if it hasn't been initialised already
-and loads the list of excluded distributions from the C<ini> file if that hasn't been loaded already. It also registers callbacks with 
+and loads the list of excluded distributions from the C<ini> file if that hasn't been loaded already. It also registers callbacks with
 the L<CPANPLUS> backend.
 
 =item C<prepare>
@@ -437,7 +446,7 @@ load the meta data that it contains and sets C<$dist-E<gt>status-E<gt>_skipbuild
 =item C<create>
 
 This runs the creation step of your distribution, by running C<make> and C<make test> for instance. The distribution is checked against
-the database to see if a C<pass> grade has already been reported for this distribution, if so then C<skiptest> is set and the testsuite 
+the database to see if a C<pass> grade has already been reported for this distribution, if so then C<skiptest> is set and the testsuite
 will not be run.
 
 If C<$dist-E<gt>status-E<gt>_skipbuild> is set to true, CPANPLUS::Dist::YACSmoke will skip the build and test stages completely and resolve
@@ -445,21 +454,12 @@ any prereqs for the distribution before adding the build directories C<blib> str
 
 =back
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
+=head1 KUDOS
 
 Based on L<CPAN::YACSmoke> by Robert Rothenberg and Barbie.
 
 Contributions and patience from Jos Boumans the L<CPANPLUS> guy!
 
-=head1 LICENSE
-
-Copyright C<(c)> Chris Williams, Jos Boumans, Robert Rothenberg and Barbie.
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for
-details.
-
 =head1 SEE ALSO
 
 L<CPANPLUS>
@@ -468,3 +468,15 @@ L<CPANPLUS::YACSmoke>
 
 L<CPAN::YACSmoke>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Chris Williams, Jos Boumans, Robert Rothenberg and Barbie.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
