@@ -1,4 +1,8 @@
 package CPANPLUS::YACSmoke;
+$CPANPLUS::YACSmoke::VERSION = '1.03_01'; # TRIAL
+
+$CPANPLUS::YACSmoke::VERSION = '1.0301';# Dist::Zilla: +PodWeaver
+#ABSTRACT: Yet Another CPANPLUS Smoke Tester
 
 use strict;
 use warnings;
@@ -19,8 +23,6 @@ use CPANPLUS::YACSmoke::ReAssemble;
 use CPANPLUS::YACSmoke::SortVers;
 use CPANPLUS::YACSmoke::IniFiles;
 
-use vars qw($VERSION);
-
 use constant DATABASE_FILE => 'cpansmoke.dat';
 use constant CONFIG_FILE   => 'cpansmoke.ini';
 use constant RECENT_FILE   => 'RECENT';
@@ -36,8 +38,6 @@ our %EXPORT_TAGS = (
 our @EXPORT_OK = ( @{ $EXPORT_TAGS{'all'} } );
 our @EXPORT    = ( @{ $EXPORT_TAGS{'default'} } );
 
-$VERSION = '1.00';
-
 {
   my %Checked;
   my $TiedObj;
@@ -97,6 +97,7 @@ sub new {
 
   my $exclude_dists;
   my $exclude_auths;
+  my $local_lib;
   my $config_file = catfile( $conf->get_conf('base'), CONFIG_FILE );
   if ( -r $config_file ) {
      my $cfg = CPANPLUS::YACSmoke::IniFiles->new(-file => $config_file);
@@ -114,6 +115,7 @@ sub new {
           $exclude_auths->add( @list );
        }
      }
+     $local_lib = $cfg->val( 'CONFIG', 'local::lib' );
   }
 
   my $self = bless { @_ }, $package;
@@ -122,6 +124,7 @@ sub new {
   $self->{exclude_dists} = $exclude_dists;
   $self->{exclude_auths} = $exclude_auths;
   $self->{allow_retries} = 'aborted|ungraded';
+  $self->{local_lib}     = $local_lib;
   return $self;
 }
 
@@ -156,6 +159,13 @@ sub test {
 
   $self->_disconnect_db();
 
+  my $target = 'create';
+
+  if ( $self->{local_lib} ) {
+     $self->_setup_local_lib();
+     $target = 'install';
+  }
+
   foreach my $mod ( @mods ) {
      eval {
 		CPANPLUS::Error->flush();
@@ -435,15 +445,36 @@ sub _get_build_dir {
   );
 }
 
+sub _setup_local_lib {
+  my $self = shift;
+  return if !$self->{local_lib};
+  require Cwd;
+  require File::Temp;
+  require CPANPLUS::YACSmoke::locallib;
+  my $tmpdir = File::Temp::tempdir( DIR => '.', CLEANUP => 1 );
+  my $abs = Cwd::abs_path($tmpdir);
+  CPANPLUS::YACSmoke::locallib->ensure_dir_structure_for( $abs, { quiet => 1 } );
+  CPANPLUS::YACSmoke::locallib->setup_env_hash_for( $abs );
 }
 
-1;
+}
+
+'Yakkity Yac';
+
 __END__
 
+=pod
+
+=encoding UTF-8
+
 =head1 NAME
 
 CPANPLUS::YACSmoke - Yet Another CPANPLUS Smoke Tester
 
+=head1 VERSION
+
+version 1.03_01
+
 =head1 SYNOPSIS
 
   perl -MCPANPLUS::YACSmoke -e test
@@ -493,6 +524,17 @@ a particular CPAN author ID.
 The above would ignore all distributions of any CPAN author ID that
 begins with C<ASS>, such as C<ASSAM> and C<ASSONIA>.
 
+Experimental support for L<local::lib> type environment has been added.
+In the C<ini> file specify the C<local::lib> setting to enable this feature.
+
+  [CONFIG]
+  local::lib = 1
+
+Setting this will make CPANPLUS::YACSmoke setup a L<local::lib> under the
+current working directory before testing starts. All modules tested (and prereqs
+resolved during testing) will be installed into the L<local::lib>. When testing
+finishes, the L<local::lib> will be removed.
+
 See L<Config::IniFiles> for more information on the INI file format.
 
 =head1 PROCEDURAL INTERFACE
@@ -561,22 +603,22 @@ is that a distribution must have a more recent version, which has previously
 been marked as a PASS. However, if one or more distributions are passed as a
 parameter list, those specific distributions will be purged.
 
-If the flush_flag is set, via the config hashref, to a true value, the directory 
+If the flush_flag is set, via the config hashref, to a true value, the directory
 path created for each older copy of a distribution is deleted.
 
 =item flush( [ 'all' | 'old' ]  )
 
   perl -MCPANPLUS::YACSmoke -e flush()
-  
+
   perl -MCPANPLUS::YACSmoke -e flush('all')
 
   perl -MCPANPLUS::YACSmoke -e flush('old')
 
 Removes unrequired build directories from the designated CPANPLUS build
-directory. Note that this deletes directories regardless of whether the 
+directory. Note that this deletes directories regardless of whether the
 associated distribution was tested.
 
-Default flush is 'all'. The 'old' option will only delete the older 
+Default flush is 'all'. The 'old' option will only delete the older
 distributions, of multiple instances of a distribution.
 
 Note that this cannot be done reliably using last access or modify time, as
@@ -598,9 +640,9 @@ Each of the procedural interface functions are available as methods of a CPANPLU
 
 =item C<new>
 
-The object interface is created normally through the test() or mark() functions of the procedural interface. 
+The object interface is created normally through the test() or mark() functions of the procedural interface.
 
-=back 
+=back
 
 =head1 ENVIRONMENT VARIABLES
 
@@ -629,31 +671,23 @@ Set to 1 to indicate that we are currently running in an automated testing envir
 
 =item C<PERL_MM_USE_DEFAULT>
 
-Set to 1 MakeMaker and Module::Build's prompt functions will always return the default 
+Set to 1 MakeMaker and Module::Build's prompt functions will always return the default
 without waiting for user input.
 
 =item C<MAILDOMAIN>
 
 L<Test::Reporter> uses this. YACSmoke will set this if it isn't already set. It will try to determine
-the domain from the C<email> setting in L<CPANPLUS>. If this is C<cpan.org> it will default to 
+the domain from the C<email> setting in L<CPANPLUS>. If this is C<cpan.org> it will default to
 C<cpantesters.org> ( the perl.org MX doesn't like people trying to impersonate it, for obvious reasons ).
 
 =back
 
-=head1 AUTHOR
-
-Chris C<BinGOs> Williams <chris@bingosnet.co.uk>
+=head1 KUDOS
 
 Based on L<CPAN::YACSmoke> by Robert Rothenberg and Barbie.
 
 Contributions and patience from Jos Boumans the L<CPANPLUS> guy!
 
-=head1 LICENSE
-
-Copyright E<copy> Chris Williams, Jos Boumans, Robert Rothenberg and Barbie.
-
-This module may be used, modified, and distributed under the same terms as Perl itself. Please see the license that came with your Perl distribution for details.
-
 =head1 SEE ALSO
 
 L<CPANPLUS>
@@ -666,4 +700,15 @@ L<CPAN::YACSmoke>
 
 L<Test::Reporter>
 
+=head1 AUTHOR
+
+Chris Williams <chris@bingosnet.co.uk>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2018 by Chris Williams, Jos Boumans, Robert Rothenberg and Barbie.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
