@@ -1,10 +1,7 @@
 package CPANPLUS::YACSmoke::IniFiles;
+$CPANPLUS::YACSmoke::IniFiles::VERSION = '1.03_01'; # TRIAL
 
-use vars qw($VERSION);
-
-$VERSION = '1.00';
-
-require 5.004;
+$CPANPLUS::YACSmoke::IniFiles::VERSION = '1.0301';require 5.004;
 use strict;
 use Carp;
 use Symbol 'gensym','qualify_to_ref';   # For the 'any data type' hack
@@ -2186,12 +2183,10 @@ sub _make_filehandle {
 # 2000.May.09 Created to excapsulate TIEHASH interface    JW
 ############################################################
 package Config::IniFiles::_section;
+$Config::IniFiles::_section::VERSION = '1.03_01'; # TRIAL
 
-use strict;
+$Config::IniFiles::_section::VERSION = '1.0301';use strict;
 use Carp;
-use vars qw( $VERSION );
-
-$CPANPLUS::YACSmoke::IniFiles::_section::VERSION = 1.00;
 
 # ----------------------------------------------------------
 # Sub: Config::IniFiles::_section::TIEHASH
