@@ -7,10 +7,9 @@
 # the same terms as Perl itself.
 
 package CPANPLUS::YACSmoke::SortVers;
-use vars '$VERSION';
-$VERSION = '1.00';
+$CPANPLUS::YACSmoke::SortVers::VERSION = '1.03_01'; # TRIAL
 
-require Exporter;
+$CPANPLUS::YACSmoke::SortVers::VERSION = '1.0301';require Exporter;
 @ISA=qw(Exporter);
 
 @EXPORT=qw(&versions &versioncmp);
